"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Promise = require("bluebird");
var ResinSdk = require("resin-sdk");
var _ = require("lodash");
var deviceConfig = require("resin-device-config");
var resin = ResinSdk.fromSharedOptions();
function generateBaseConfig(application, options) {
    options = _.mapValues(options, function (value, key) {
        if (key === 'appUpdatePollInterval') {
            return value * 60 * 1000;
        }
        else {
            return value;
        }
    });
    return Promise.props({
        userId: resin.auth.getUserId(),
        username: resin.auth.whoami(),
        apiUrl: resin.settings.get('apiUrl'),
        vpnUrl: resin.settings.get('vpnUrl'),
        registryUrl: resin.settings.get('registryUrl'),
        deltaUrl: resin.settings.get('deltaUrl'),
        apiConfig: resin.models.config.getAll(),
    }).then(function (results) {
        return deviceConfig.generate({
            application: application,
            user: {
                id: results.userId,
                username: results.username,
            },
            endpoints: {
                api: results.apiUrl,
                vpn: results.vpnUrl,
                registry: results.registryUrl,
                delta: results.deltaUrl,
            },
            pubnub: results.apiConfig.pubnub,
            mixpanel: {
                token: results.apiConfig.mixpanelToken,
            },
        }, options);
    });
}
exports.generateBaseConfig = generateBaseConfig;
function generateApplicationConfig(application, options) {
    return generateBaseConfig(application, options).tap(function (config) {
        return addApplicationKey(config, application.id);
    });
}
exports.generateApplicationConfig = generateApplicationConfig;
function generateDeviceConfig(device, deviceApiKey, options) {
    return resin.models.application
        .get(device.application_name)
        .then(function (application) {
        return generateBaseConfig(application, options).tap(function (config) {
            if (deviceApiKey) {
                return addDeviceKey(config, device.uuid, deviceApiKey);
            }
            else {
                return addApplicationKey(config, application.id);
            }
        });
    })
        .then(function (config) {
        config.registered_at = Math.floor(Date.now() / 1000);
        config.deviceId = device.id;
        config.uuid = device.uuid;
        return config;
    });
}
exports.generateDeviceConfig = generateDeviceConfig;
function addApplicationKey(config, applicationNameOrId) {
    return resin.models.application
        .generateApiKey(applicationNameOrId)
        .tap(function (apiKey) {
        config.apiKey = apiKey;
    });
}
function addDeviceKey(config, uuid, customDeviceApiKey) {
    return Promise.try(function () {
        return customDeviceApiKey || resin.models.device.generateDeviceKey(uuid);
    }).tap(function (deviceApiKey) {
        config.deviceApiKey = deviceApiKey;
    });
}
//# sourceMappingURL=config.js.map